@@ -69,6 +69,8 @@ seq_dist <- function(a, b
     , p >= 0
     , ifelse(method %in% c('osa','dl'), length(weight) >= 4, TRUE)
     , ifelse(method %in% c('lv','jw') , length(weight) >= 3, TRUE)
+    , length(nthread) == 1
+    , is.numeric(nthread)
     , nthread > 0
   )
   
