@@ -8,11 +8,19 @@ options(sd_num_thread=2)
    expect_error(stringdist("a","b",weight=c(-1,1,1,1)))
    expect_error(stringdist("a","b",weight=c(1,0,1,1)))
    expect_error(stringdist("a","b",weight=c(1,1,1,4)))
+   expect_error(stringdist("a","b",nthread=1:4))
+   expect_error(stringdist("a","b",nthread="foo"))
+   expect_error(stringdist("a","b",nthread=integer(0)))
+   expect_error(stringdist("a","b",nthread=NULL))
    expect_warning(stringdist(letters[1:3],letters[1:2]))
    expect_warning(stringdist(list('a'),'a'))
    expect_warning(stringdist('a',list('a')))
    expect_warning(stringdistmatrix(list('a')))
    expect_warning(stringdistmatrix(list('a'),list('b')))
+   expect_error(stringdistmatrix("a","b",nthread=1:4))
+   expect_error(stringdistmatrit("a","b",nthread="foo"))
+   expect_error(stringdistmatrit("a","b",nthread=integer(0)))
+   expect_error(stringdistmatrit("a","b",nthread=NULL))
 
 
 
